==> centreon-web-24.04.19.tar.gz: centreon-web-24.04.19/src/Centreon/Domain/Contact/Interfaces/ContactRepositoryInterface.php <==
<?php

/*
 * Copyright 2005-2019 Centreon
 * Centreon is developped by : Julien Mathis and Romain Le Merlus under
 * GPL Licence 2.0.
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation ; either version 2 of the License.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, see <http://www.gnu.org/licenses>.
 *
 * Linking this program statically or dynamically with other modules is making a
 * combined work based on this program. Thus, the terms and conditions of the GNU
 * General Public License cover the whole combination.
 *
 * As a special exception, the copyright holders of this program give Centreon
 * permission to link this program with independent modules to produce an executable,
 * regardless of the license terms of these independent modules, and to copy and
 * distribute the resulting executable under terms of Centreon choice, provided that
 * Centreon also meet, for each linked independent module, the terms  and conditions
 * of the license of that module. An independent module is a module which is not
 * derived from this program. If you modify this program, you may extend this
 * exception to your version of the program, but you are not obliged to do so. If you
 * do not wish to do so, delete this exception statement from your version.
 *
 * For more information : contact@centreon.com
 *
 */
declare(strict_types=1);

namespace Centreon\Domain\Contact\Interfaces;

use Centreon\Domain\Contact\Contact;

interface ContactRepositoryInterface
{
    /**
     * Find a contact by name.
     *
     * @param string $name Username
     * @return Contact|null
     * @throws \Exception
     */
    public function findByName(string $name): ?Contact;

    /**
     * Find a contact by email.
     *
     * @param string $email email
     * @return Contact|null
     * @throws \Exception
     */
    public function findByEmail(string $email): ?Contact;

    /**
     * Find a contact by id
     *
     * @param int $contactId Contact id
     * @return Contact|null
     */
    public function findById(int $contactId): ?Contact;

    /**
     * Find a contact based on their session id
     *
     * @param string $sessionId Session id
     * @return Contact|null
     */
    public function findBySession(string $sessionId): ?Contact;

    /**
     * Find a contact by an authentication token
     * @param string $token
     * @return Contact|null
     */
    public function findByAuthenticationToken(string $token): ?Contact;

    /**
     * Check existence of provided contacts
     * Return an array of the existing user IDs out of the provided ones.
     *
     * @param int[] $contactIds
     * @return int[]
     */
    public function exist(array $contactIds): array;
}

==> centreon-web-24.10.14.tar.gz: centreon-web-24.10.14/src/Centreon/Domain/Contact/Interfaces/ContactRepositoryInterface.php <==
<?php

/*
 * Copyright 2005-2019 Centreon
 * Centreon is developped by : Julien Mathis and Romain Le Merlus under
 * GPL Licence 2.0.
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation ; either version 2 of the License.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, see <http://www.gnu.org/licenses>.
 *
 * Linking this program statically or dynamically with other modules is making a
 * combined work based on this program. Thus, the terms and conditions of the GNU
 * General Public License cover the whole combination.
 *
 * As a special exception, the copyright holders of this program give Centreon
 * permission to link this program with independent modules to produce an executable,
 * regardless of the license terms of these independent modules, and to copy and
 * distribute the resulting executable under terms of Centreon choice, provided that
 * Centreon also meet, for each linked independent module, the terms  and conditions
 * of the license of that module. An independent module is a module which is not
 * derived from this program. If you modify this program, you may extend this
 * exception to your version of the program, but you are not obliged to do so. If you
 * do not wish to do so, delete this exception statement from your version.
 *
 * For more information : contact@centreon.com
 *
 */
declare(strict_types=1);

namespace Centreon\Domain\Contact\Interfaces;

use Centreon\Domain\Contact\BasicContact;
use Centreon\Domain\Contact\Contact;
use Core\Security\AccessGroup\Domain\Model\AccessGroup;

interface ContactRepositoryInterface
{
    /**
     * Find a contact by name.
     *
     * @param string $name Username
     * @return Contact|null
     * @throws \Exception
     */
    public function findByName(string $name): ?Contact;

    /**
     * Find a contact by email.
     *
     * @param string $email email
     * @return Contact|null
     * @throws \Exception
     */
    public function findByEmail(string $email): ?Contact;

    /**
     * Find a contact by id
     *
     * @param int $contactId Contact id
     * @return Contact|null
     */
    public function findById(int $contactId): ?Contact;

    /**
     * Find a contact based on their session id
     *
     * @param string $sessionId Session id
     * @return Contact|null
     */
    public function findBySession(string $sessionId): ?Contact;

    /**
     * Find a contact by an authentication token
     * @param string $token
     * @return Contact|null
     */
    public function findByAuthenticationToken(string $token): ?Contact;
}
